@@ -160,7 +160,8 @@ public:
      *         Package::State change flag.
      * @since 1.3
      */
-    QHash<Package::State, PackageList> stateChanges(CacheState oldState, PackageList excluded) const;
+    QHash<Package::State, PackageList> stateChanges(const CacheState &oldState,
+                                                    const PackageList &excluded) const;
 
     /**
      * Pointer to the QApt Backend's config object.
@@ -469,7 +470,7 @@ Q_SIGNALS:
     /**
      * Emits the progress of the Apt Xapian Indexer
      *
-     * @param progress The progress percentage of the indexer
+     * @param percentage The progress percentage of the indexer
      */
     void xapianUpdateProgress(int percentage);
 
